@@ -11,7 +11,7 @@ use Moo;
 use namespace::clean;
 
 # Version.
-our $VERSION = 0.06;
+our $VERSION = 0.07;
 
 # Get XML.
 has xml => (
@@ -38,6 +38,8 @@ Map::Tube::Bucharest - Interface to the Bucharest Metro Map.
  use Map::Tube::Bucharest;
  my $obj = Map::Tube::Bucharest->new;
  my $routes_ar = $obj->get_all_routes($from, $to);
+ my $line = $obj->get_line_by_id($line_id);
+ my $line = $obj->get_line_by_name($line_name);
  my $lines_ar = $obj->get_lines;
  my $station = $obj->get_node_by_id($station_id);
  my $station = $obj->get_node_by_name($station_name);
@@ -66,10 +68,20 @@ For more information about Bucharest Map, click L<here|https://en.wikipedia.org/
  Get all routes from station to station.
  Returns reference to array with Map::Tube::Route objects.
 
+=item C<get_line_by_id($line_id)>
+
+ Get line object defined by id.
+ Returns Map::Tube::Line object.
+
+=item C<get_line_by_name($line_name)>
+
+ Get line object defined by name.
+ Returns Map::Tube::Line object.
+
 =item C<get_lines()>
 
  Get lines in metro map.
- Returns reference to array with Map::Tube::Line objects.
+ Returns reference to unsorted array with Map::Tube::Line objects.
 
 =item C<get_node_by_id($station_id)>
 
@@ -185,6 +197,31 @@ For more information about Bucharest Map, click L<here|https://en.wikipedia.org/
 
 =end html
 
+=head1 EXAMPLE4
+
+ # Pragmas.
+ use strict;
+ use warnings;
+
+ # Modules.
+ use Encode qw(encode_utf8);
+ use Map::Tube::Bucharest;
+
+ # Object.
+ my $obj = Map::Tube::Bucharest->new;
+
+ # Get lines.
+ my $lines_ar = $obj->get_lines;
+
+ # Print out.
+ map { print encode_utf8($_->name)."\n"; } sort @{$lines_ar};
+
+ # Output:
+ # Linia M1
+ # Linia M2
+ # Linia M3
+ # Linia M4
+
 =head1 DEPENDENCIES
 
 L<File::Share>,
@@ -228,6 +265,6 @@ L<http://skim.cz>
 
 =head1 VERSION
 
-0.06
+0.07
 
 =cut
